@@ -28,6 +28,7 @@
 #define HAVE_SYSEXITS_H 1
 #define C_STACK_GROWS_DOWNWARD 1
 #define C_USE_STD_FEATURE_MACROS
+ /* (this build was optimized for speed) */
 #define C_CHICKEN_PROGRAM "chicken"
 #ifndef C_INSTALL_CC
 # define C_INSTALL_CC "gcc"
@@ -42,10 +43,10 @@
 # define C_INSTALL_RC_COMPILER ""
 #endif
 #ifndef C_INSTALL_CFLAGS
-# define C_INSTALL_CFLAGS "-fno-strict-aliasing -fwrapv -DHAVE_CHICKEN_CONFIG_H -DC_ENABLE_PTABLES -Os -fomit-frame-pointer"
+# define C_INSTALL_CFLAGS "-fno-strict-aliasing -fwrapv -DHAVE_CHICKEN_CONFIG_H -Wl,--as-needed -ffat-lto-objects -march=armv8-a -O2 -pipe -fno-plt -fexceptions         -Wp,-D_FORTIFY_SOURCE=3 -Wformat -Werror=format-security         -fstack-clash-protection -w -O3 -fomit-frame-pointer"
 #endif
 #ifndef C_INSTALL_LDFLAGS
-# define C_INSTALL_LDFLAGS " "
+# define C_INSTALL_LDFLAGS "-Wl,--as-needed -Wl,-O1 -Wl,--sort-common -Wl,--as-needed -Wl,-z,relro -Wl,-z,now "
 #endif
 #ifndef C_INSTALL_PREFIX
 # define C_INSTALL_PREFIX "/usr"
@@ -57,7 +58,7 @@
 # define C_INSTALL_BIN_HOME "/usr/bin"
 #endif
 #ifndef C_INSTALL_EGG_HOME
-# define C_INSTALL_EGG_HOME "/usr/lib/chicken/9"
+# define C_INSTALL_EGG_HOME "/usr/lib/chicken/11"
 #endif
 #ifndef C_INSTALL_LIB_HOME
 # define C_INSTALL_LIB_HOME "/usr/lib"
@@ -95,14 +96,20 @@
 #ifndef C_TARGET_RC_COMPILER
 # define C_TARGET_RC_COMPILER ""
 #endif
+#ifndef C_TARGET_LIBRARIAN
+# define C_TARGET_LIBRARIAN "ar"
+#endif
 #ifndef C_TARGET_INSTALL_PROGRAM
 # define C_TARGET_INSTALL_PROGRAM "install"
 #endif
 #ifndef C_TARGET_CFLAGS
-# define C_TARGET_CFLAGS "-fno-strict-aliasing -fwrapv -DHAVE_CHICKEN_CONFIG_H -DC_ENABLE_PTABLES -Os -fomit-frame-pointer"
+# define C_TARGET_CFLAGS "-fno-strict-aliasing -fwrapv -DHAVE_CHICKEN_CONFIG_H -Wl,--as-needed -ffat-lto-objects -march=armv8-a -O2 -pipe -fno-plt -fexceptions         -Wp,-D_FORTIFY_SOURCE=3 -Wformat -Werror=format-security         -fstack-clash-protection -w -O3 -fomit-frame-pointer"
+#endif
+#ifndef C_TARGET_LIBRARIAN_FLAGS
+# define C_TARGET_LIBRARIAN_FLAGS "cru"
 #endif
 #ifndef C_TARGET_LDFLAGS
-# define C_TARGET_LDFLAGS " "
+# define C_TARGET_LDFLAGS "-Wl,--as-needed -Wl,-O1 -Wl,--sort-common -Wl,--as-needed -Wl,-z,relro -Wl,-z,now "
 #endif
 #ifndef C_TARGET_INSTALL_PROGRAM_EXECUTABLE_OPTIONS
 # define C_TARGET_INSTALL_PROGRAM_EXECUTABLE_OPTIONS "-m 755"
@@ -132,7 +139,7 @@
 # define C_TARGET_RUN_LIB_HOME "/usr/lib"
 #endif
 #ifndef C_TARGET_SHARE_HOME
-# define C_TARGET_SHARE_HOME "/usr/share"
+# define C_TARGET_SHARE_HOME "/usr/share/chicken"
 #endif
 #ifndef C_TARGET_INCLUDE_HOME
 # define C_TARGET_INCLUDE_HOME "/usr/include/chicken"
@@ -144,10 +151,10 @@
 # define C_CHICKEN_PROGRAM "chicken"
 #endif
 #ifndef C_CSC_PROGRAM
-# define C_CSC_PROGRAM "csc"
+# define C_CSC_PROGRAM "chicken-csc"
 #endif
 #ifndef C_CSI_PROGRAM
-# define C_CSI_PROGRAM "csi"
+# define C_CSI_PROGRAM "chicken-csi"
 #endif
 #ifndef C_CHICKEN_DO_PROGRAM
 # define C_CHICKEN_DO_PROGRAM "chicken-do"
@@ -165,7 +172,7 @@
 # define C_WINDOWS_SHELL 0
 #endif
 #ifndef C_BINARY_VERSION
-# define C_BINARY_VERSION 9
+# define C_BINARY_VERSION 11
 #endif
 #ifndef C_USES_SONAME
 # define C_USES_SONAME 1
